========
Examples
========

Longer usage examples of how to use skan to analyze and visualize real data.


.. toctree::
   :maxdepth: 1

   complete_analysis
   sholl_analysis
   visualizing_3d_skeletons
